==> tivio_sdk-1.7.3.tar.gz: lib/tivio.dart <==
library tivio;

import 'dart:async';
import 'package:sentry/sentry.dart';
import 'bridge.dart';
import 'dto.dart';
import 'player/tivio_player_wrapper.dart';
import 'utils/enum.dart';
import 'streams.dart';
import 'logger.dart';
import 'enums/tivio_languages.dart';
import 'enums/tivio_log_levels.dart';
export 'dto.dart';
export 'player/tivio_player.dart';
export 'player/tivio_player_controller.dart';
export 'player/tivio_player_input_source.dart';
export 'player/tivio_player_wrapper.dart';
export 'player/tivio_player_colors.dart';
export 'player/tivio_player_layout.dart';
export 'streams.dart';
export 'enums/tivio_languages.dart';
export 'enums/tivio_log_levels.dart';
export 'enums/tivio_player_layout.dart';

class Tivio {
  final String secret;
  final TivioLanguages language;
  final TivioLogLevels logLevel;
  final bool development;
  final Logger _logger = Logger();
  final Bridge _bridge = Bridge();

  Tivio({
    required this.secret,
    required this.language,
    required this.logLevel,
    required this.development,
  });

  Future<Tivio> init() async {
    await _logger.init(
      logLevel: logLevel,
      sentryDsn: 'https://912a127df2c74b8e8e3e8d74f9f3c628@o507550.ingest.sentry.io/5668188',
      development: development,
    );

    this._logger.debug('Tivio: init started');

    await _bridge.init(secret, enumToString(language), this.development);

    this._logger.debug('Tivio: init completed');
    return this;
  }

  Future<void> setUser(String userId, dynamic payload,
      {dynamic additionalUserData}) =>
      _bridge.setUser(userId, payload, additionalUserData: additionalUserData);

  Future<void> setLanguage(TivioLanguages language) =>
      _bridge.setLanguage(enumToString(language));

  Future<TivioPlayerWrapper> getPlayer(String id) => _bridge.getPlayer(id);

  /// API 1.0.0

  /// Widget

  TivioDataStream<TivioDataWidget>? subscribeToWidget({
    required String widgetId,
  }) {
    return _bridge.subscribeToWidget(widgetId: widgetId);
  }

  /// Channel

  TivioDataStream<
      TivioDataPagination<TivioDataChannel>>? subscribeToChannelsInWidget({
    required String widgetId,
    int count = 10,
  }) {
    return _bridge.subscribeToChannelsInWidget(
        widgetId: widgetId, count: count);
  }

  fetchNextChannelsInWidget({
    required String widgetId,
    int count = 10,
  }) {
    return _bridge.fetchNextChannelsInWidget(widgetId: widgetId, count: count);
  }

  TivioDataStream<TivioDataChannel>? subscribeToChannel({
    required String channelId,
  }) {
    return _bridge.subscribeToChannel(channelId: channelId);
  }

  /// Section

  TivioDataStream<
      TivioDataPagination<TivioDataSection>>? subscribeToSectionsInChannel({
    required String channelId,
    int count = 10,
  }) {
    return _bridge.subscribeToSectionsInChannel(
        channelId: channelId, count: count);
  }

  fetchNextSectionsInChannel({
    required String channelId,
    int count = 10,
  }) {
    return _bridge.fetchNextSectionsInChannel(
        channelId: channelId, count: count);
  }

  TivioDataStream<TivioDataSection>? subscribeToSection({
    required String sectionId,
  }) {
    return _bridge.subscribeToSection(sectionId: sectionId);
  }

  /// Video

  TivioDataStream<
      TivioDataPagination<TivioDataVideo>>? subscribeToVideosInSection({
    required String sectionId,
    int count = 10,
  }) {
    return _bridge.subscribeToVideosInSection(
        sectionId: sectionId, count: count);
  }

  fetchNextVideosInSection({
    required String sectionId,
    int count = 10,
  }) {
    return _bridge.fetchNextVideosInSection(sectionId: sectionId, count: count);
  }

  TivioDataStream<TivioDataVideo>? subscribeToVideo({
    required String videoId,
  }) {
    return _bridge.subscribeToVideo(videoId: videoId);
  }

  /// Recent

  TivioDataStream<
      TivioDataPagination<TivioDataVideo>>? subscribeToRecentVideosInWidget({
    required String widgetId,
    int count = 10,
  }) {
    return _bridge.subscribeToRecentVideosInWidget(
        widgetId: widgetId, count: count);
  }

  TivioDataStream<
      TivioDataPagination<TivioDataVideo>>? subscribeToRecentVideosInChannel({
    required String channelId,
    int count = 10,
  }) {
    return _bridge.subscribeToRecentVideosInChannel(
        channelId: channelId, count: count);
  }

  /// Screens

  TivioDataStream<TivioDataScreen>? subscribeToScreen({
    required String screenId,
  }) {
    return _bridge.subscribeToScreen(screenId: screenId);
  }

  TivioDataStream<TivioDataPagination<TivioDataRowItem>>? subscribeToItemsInRow(
      {
        required String rowId,
        int count = 10,
      }) {
    return _bridge.subscribeToItemsInRow(rowId: rowId, count: count);
  }

  TivioDataStream<TivioDataPagination<TivioUser>>? subscribeToUser() {
    return _bridge.subscribeToUser();
  }

  fetchNextItemsInRow({
    required String rowId,
    int count = 10,
  }) {
    return _bridge.fetchNextItemsInRow(rowId: rowId, count: count);
  }

  /// Search

  Future<TivioDataPagination<TivioDataChannel>> searchChannels({
    required String query,
    int limit = 10,
  }) {
    return _bridge.searchChannels(query, limit);
  }

  Future<TivioDataPagination<TivioDataVideo>> searchVideos({
    required String query,
    int limit = 10,
  }) {
    return _bridge.searchVideos(query, limit);
  }
}

Future<Tivio> initTivio({
  required String secret,
  TivioLanguages language = TivioLanguages.en,
  TivioLogLevels logLevel = TivioLogLevels.nothing,
  bool development = false,
}) {
  return Tivio(secret: secret,
      language: language,
      logLevel: logLevel,
      development: development).init();
}

==> tivio_sdk-1.7.5.tar.gz: lib/tivio.dart <==
library tivio;

import 'dart:async';
import 'package:sentry/sentry.dart';
import 'bridge.dart';
import 'dto.dart';
import 'player/tivio_player_wrapper.dart';
import 'utils/enum.dart';
import 'streams.dart';
import 'logger.dart';
import 'enums/tivio_languages.dart';
import 'enums/tivio_log_levels.dart';
export 'dto.dart';
export 'player/tivio_player.dart';
export 'player/tivio_player_controller.dart';
export 'player/tivio_player_input_source.dart';
export 'player/tivio_player_wrapper.dart';
export 'player/tivio_player_colors.dart';
export 'player/tivio_player_layout.dart';
export 'streams.dart';
export 'enums/tivio_languages.dart';
export 'enums/tivio_log_levels.dart';
export 'enums/tivio_player_layout.dart';

class Tivio {
  final String secret;
  final TivioLanguages language;
  final TivioLogLevels logLevel;
  final bool development;
  final Logger _logger = Logger();
  final Bridge _bridge = Bridge();

  Tivio({
    required this.secret,
    required this.language,
    required this.logLevel,
    required this.development,
  });

  Future<Tivio> init() async {
    await _logger.init(
      logLevel: logLevel,
      sentryDsn: 'https://912a127df2c74b8e8e3e8d74f9f3c628@o507550.ingest.sentry.io/5668188',
      development: development,
    );

    this._logger.debug('Tivio: init started');

    await _bridge.init(secret, enumToString(language), this.development);

    this._logger.debug('Tivio: init completed');
    return this;
  }

  Future<void> setUser(String userId, dynamic payload,
      {dynamic additionalUserData}) =>
      _bridge.setUser(userId, payload, additionalUserData: additionalUserData);

  Future<void> setLanguage(TivioLanguages language) =>
      _bridge.setLanguage(enumToString(language));

  Future<TivioPlayerWrapper> getPlayer(String id) => _bridge.getPlayer(id);

  /// API 1.0.0

  /// Widget

  TivioDataStream<TivioDataWidget>? subscribeToWidget({
    required String widgetId,
  }) {
    return _bridge.subscribeToWidget(widgetId: widgetId);
  }

  /// Channel

  TivioDataStream<
      TivioDataPagination<TivioDataChannel>>? subscribeToChannelsInWidget({
    required String widgetId,
    int count = 10,
  }) {
    return _bridge.subscribeToChannelsInWidget(
        widgetId: widgetId, count: count);
  }

  fetchNextChannelsInWidget({
    required String widgetId,
    int count = 10,
  }) {
    return _bridge.fetchNextChannelsInWidget(widgetId: widgetId, count: count);
  }

  TivioDataStream<TivioDataChannel>? subscribeToChannel({
    required String channelId,
  }) {
    return _bridge.subscribeToChannel(channelId: channelId);
  }

  /// Section

  TivioDataStream<
      TivioDataPagination<TivioDataSection>>? subscribeToSectionsInChannel({
    required String channelId,
    int count = 10,
  }) {
    return _bridge.subscribeToSectionsInChannel(
        channelId: channelId, count: count);
  }

  fetchNextSectionsInChannel({
    required String channelId,
    int count = 10,
  }) {
    return _bridge.fetchNextSectionsInChannel(
        channelId: channelId, count: count);
  }

  TivioDataStream<TivioDataSection>? subscribeToSection({
    required String sectionId,
  }) {
    return _bridge.subscribeToSection(sectionId: sectionId);
  }

  /// Video

  TivioDataStream<
      TivioDataPagination<TivioDataVideo>>? subscribeToVideosInSection({
    required String sectionId,
    int count = 10,
  }) {
    return _bridge.subscribeToVideosInSection(
        sectionId: sectionId, count: count);
  }

  fetchNextVideosInSection({
    required String sectionId,
    int count = 10,
  }) {
    return _bridge.fetchNextVideosInSection(sectionId: sectionId, count: count);
  }

  TivioDataStream<TivioDataVideo>? subscribeToVideo({
    required String videoId,
  }) {
    return _bridge.subscribeToVideo(videoId: videoId);
  }

  /// Recent

  TivioDataStream<
      TivioDataPagination<TivioDataVideo>>? subscribeToRecentVideosInWidget({
    required String widgetId,
    int count = 10,
  }) {
    return _bridge.subscribeToRecentVideosInWidget(
        widgetId: widgetId, count: count);
  }

  TivioDataStream<
      TivioDataPagination<TivioDataVideo>>? subscribeToRecentVideosInChannel({
    required String channelId,
    int count = 10,
  }) {
    return _bridge.subscribeToRecentVideosInChannel(
        channelId: channelId, count: count);
  }

  /// Screens

  TivioDataStream<TivioDataScreen>? subscribeToScreen({
    required String screenId,
  }) {
    return _bridge.subscribeToScreen(screenId: screenId);
  }

  TivioDataStream<TivioDataPagination<TivioDataRowItem>>? subscribeToItemsInRow(
      {
        required String rowId,
        int count = 10,
      }) {
    return _bridge.subscribeToItemsInRow(rowId: rowId, count: count);
  }

  TivioDataStream<TivioUser>? subscribeToUser() {
    return _bridge.subscribeToUser();
  }

  fetchNextItemsInRow({
    required String rowId,
    int count = 10,
  }) {
    return _bridge.fetchNextItemsInRow(rowId: rowId, count: count);
  }

  /// Search

  Future<TivioDataPagination<TivioDataChannel>> searchChannels({
    required String query,
    int limit = 10,
  }) {
    return _bridge.searchChannels(query, limit);
  }

  Future<TivioDataPagination<TivioDataVideo>> searchVideos({
    required String query,
    int limit = 10,
  }) {
    return _bridge.searchVideos(query, limit);
  }
}

Future<Tivio> initTivio({
  required String secret,
  TivioLanguages language = TivioLanguages.en,
  TivioLogLevels logLevel = TivioLogLevels.nothing,
  bool development = false,
}) {
  return Tivio(secret: secret,
      language: language,
      logLevel: logLevel,
      development: development).init();
}
